@@ -130,6 +130,8 @@ class SyncKohaRowsCommand(BaseCommand):
                         record[key] = SyncKohaRowsCommand.sanitize(record[key])
                     if key == "tr_value":
                         record[key] = int(record[key]) if record[key] is not None else 0
+                    if key in ["account", "indexed", "item_biblio_number"]:
+                        record[key] = int(record[key])
 
         post_rows_req = requests.post(f"{Config.config['target']['url_add']}/{self.add}",
                                       json={
